""" simple description
this is a placeholder for python packages
"""


def convert(path):
    """ Convert th given pdf to text

    Parameters:
    path(str): the path to pdf file

    Returns:
    str: the content of the pdf file as text
    """
    print("pdf2Text")
